# 🌺 LilliePy 🌺 #

## 🌷 Getting Started ~ 🌷 ##

🌸 first make sure that all requirements are downloaded, this should already be done, if not then write the following command-
```bash
  pip install lilliepy
```

## 🌷 Running Lillie ~ 🌷 ##

🌸 to start the project, run-
```bash
  python lillie.config.py
```

# ❤️Thanks Too!❤️ #

<img src="https://raw.githubusercontent.com/reactive-python/reactpy/refs/heads/main/branding/png/reactpy-logo-landscape.png" alt="reactpy" width="300px" height="100px"/>
<img src="https://miro.medium.com/v2/resize:fit:618/0*FBXoiXHbZe5ssPho.png" alt="flask" width="300px" height="100px"/>